# IOOS QC

[![conda_forge_package](https://anaconda.org/conda-forge/ioos_qc/badges/version.svg)](https://anaconda.org/conda-forge/ioos_qc)
[![Default-Tests](https://github.com/ioos/ioos_qc/actions/workflows/tests.yml/badge.svg)](https://github.com/ioos/ioos_qc/actions/workflows/tests.yml)

Collection of utilities, scripts and tests to assist in automated
quality assurance and quality control for oceanographic datasets and
observing systems.

[Code](https://github.com/ioos/ioos_qc) \|
[Issues](https://github.com/ioos/ioos_qc/issues) \|
[Documentation](https://ioos.github.io/ioos_qc/)
